# Edgy Graph

The Typed Graph Library for Python

<div class="grid" markdown>
  <a href="api/graphs/" class="md-button md-button--primary">📖 API Reference</a>
  <a href="https://github.com/mathisxy/edgygraph" target="_blank" class="md-button">🔗 GitHub</a>
</div>

## Installation
```
pip install edgygraph
```

> Requires Python 3.13